/*
 * This software has been created by Genome Research Limited (GRL). 
 * GRL hereby grants permission to use, copy, modify and distribute 
 * this software and its documentation for non-commercial purposes 
 * without fee at the user's own risk on the basis set out below.
 * GRL neither undertakes nor accepts any duty whether contractual or 
 * otherwise in connection with the software, its use or the use of 
 * any derivative, and makes no representations or warranties, express
 * or implied, concerning the software, its suitability, fitness for
 * a particular purpose or non-infringement.
 * In no event shall the authors of the software or GRL be 
 * responsible or liable for any loss or damage whatsoever arising in
 * any way directly or indirectly out of the use of this software or 
 *  its derivatives, even if advised of the possibility of such damage.
 * Our software can be freely distributed under the conditions set 
 * out above, and must contain this copyright notice.
 */

#include <io_lib/scf.h>
#include "trace_align.h"

static const char *cvsid = "$Id: make_sample_data.c 18816 2006-08-03 16:39:42Z rmd $";

/**
 * Extracts the trace data from a SCF object and converts this into
 * a slightly more manageable format. This toutin also deals with 
 * performing a uniform mapping of 8 and 18 bit trace data into
 * integer storage.
 *
 * @param scf is the Scf structure representing the input trace data.
 * @param trace_start the location in the trace that should be used as
 *        the starting location in the sequence.
 * @param samples is the total number of samples to be extracted.
 *
 * @returns a sample_matrix which contains the trace data.
 * @see alloc_sample_matrix
 */
int **
make_sample_data(Scf * scf, int trace_start, int samples)
{
    Header h = scf->header;
    int **sample_data = alloc_sample_matrix(samples);
    Samples1 *s1;
    Samples2 *s2;
    int c;

    if (h.sample_size == 2) {	/* 16-bit data */
	s2 = &scf->samples.samples2[trace_start];
	for (c = 0; c < samples; c++, s2++) {
	    sample_data[base_a][c] = (int) s2->sample_A;
	    sample_data[base_c][c] = (int) s2->sample_C;
	    sample_data[base_g][c] = (int) s2->sample_G;
	    sample_data[base_t][c] = (int) s2->sample_T;
	}
    } else {			/* 8-bit */
	s1 = &scf->samples.samples1[trace_start];
	for (c = 0; c < samples; c++, s1++) {
	    sample_data[base_a][c] = (int) s1->sample_A;
	    sample_data[base_c][c] = (int) s1->sample_C;
	    sample_data[base_g][c] = (int) s1->sample_G;
	    sample_data[base_t][c] = (int) s1->sample_T;
	}
    }

    return sample_data;
}
