/*
 * This software has been created by Genome Research Limited (GRL). 
 * GRL hereby grants permission to use, copy, modify and distribute 
 * this software and its documentation for non-commercial purposes 
 * without fee at the user's own risk on the basis set out below.
 * GRL neither undertakes nor accepts any duty whether contractual or 
 * otherwise in connection with the software, its use or the use of 
 * any derivative, and makes no representations or warranties, express
 * or implied, concerning the software, its suitability, fitness for
 * a particular purpose or non-infringement.
 * In no event shall the authors of the software or GRL be 
 * responsible or liable for any loss or damage whatsoever arising in
 * any way directly or indirectly out of the use of this software or 
 *  its derivatives, even if advised of the possibility of such damage.
 * Our software can be freely distributed under the conditions set 
 * out above, and must contain this copyright notice.
 */

#include "trace_align.h"

static const char *cvsid = "$Id: trace_envelope.c 10638 2003-04-15 09:15:12Z dgm $";

/**
 * Returns the maximum value exhibited by the channels, 'ACTG'. It thus
 * returns the trace 'envelope'.
 * max_trace[c] returns the max trace (ie envelope), and max_trace2
 * the second-max
 *
 * @param samples is the number of samples stored in the sample_data
 *        array.
 * @param sample_data is the array representing the samples. The primary
 *        dimension is the length provided in the 'samples' parameter. The
 *        second dimension runs from base_a to base_t (enumeration).
 * @see base_types
 * @param max_trace is a return parameter and should be the same length as the
 *        principal dimension of sample_data (i.e. 'samples' in length). Its
 *        value at each index is the maximum value exhibited by any of
 *        the trace channels.
 * @param max_trace2 is a return parameter and should be the same length as the
 *        principal dimension of sample_data (i.e. 'samples' in length). Its
 *        value, at each index, is the second greatest value exhibited by
 *        all the trace channels.
 */
void
trace_envelope(int samples, int **sample_data, int *max_trace, int *max_trace2)
{
    int c, i;

    for (c = 0; c < samples; c++) {
	max_trace[c] = -1;
	max_trace2[c] = -2;
	for (i = base_a; i <= base_t; i++) {
	    if (max_trace[c] < sample_data[i][c]) {
		max_trace2[c] = max_trace[c];
		max_trace[c] = sample_data[i][c];
	    } else if (max_trace2[c] < sample_data[i][c]) {
		max_trace2[c] = sample_data[i][c];
	    }
	}
    }
}
