/*
 * This software has been created by Genome Research Limited (GRL). 
 * GRL hereby grants permission to use, copy, modify and distribute 
 * this software and its documentation for non-commercial purposes 
 * without fee at the user's own risk on the basis set out below.
 * GRL neither undertakes nor accepts any duty whether contractual or 
 * otherwise in connection with the software, its use or the use of 
 * any derivative, and makes no representations or warranties, express
 * or implied, concerning the software, its suitability, fitness for
 * a particular purpose or non-infringement.
 * In no event shall the authors of the software or GRL be 
 * responsible or liable for any loss or damage whatsoever arising in
 * any way directly or indirectly out of the use of this software or 
 *  its derivatives, even if advised of the possibility of such damage.
 * Our software can be freely distributed under the conditions set 
 * out above, and must contain this copyright notice.
 */

#include <stdio.h>
#include <io_lib/scf.h>
#include <rescale16bit.h>

static const char *cvsid = "$Id: rescale16bit.c 18816 2006-08-03 16:39:42Z rmd $";

#define MAX_TRACE_VAL_16 65535
#define MAX_TRACE_VAL_8    255


/**
 * Rescale an 8 bit (resolution) trace into a 16 bit trace.
 * 8 bit scf traces are scaled so the biggest value is always 255
 * so for now trace_edit reqires that 16 bit scf traces should
 * also be scaled - even though it's probably not right
 *
 * @param scf is a valid Scf data structure representing a trace.
 */
void
rescale16bit(Scf * scf)
{

    int sampleNum;
    int maxVal = 0;
    double scale;
    Samples2 *samples = scf->samples.samples2;
    for (sampleNum = 0; sampleNum < scf->header.samples; sampleNum++) {
	Samples2 *sample = &samples[sampleNum];
	if (sample->sample_A > maxVal)
	    maxVal = sample->sample_A;
	if (sample->sample_C > maxVal)
	    maxVal = sample->sample_C;
	if (sample->sample_G > maxVal)
	    maxVal = sample->sample_G;
	if (sample->sample_T > maxVal)
	    maxVal = sample->sample_T;
    }
    scale = (maxVal) ? (((double) MAX_TRACE_VAL_16) / (double) maxVal) : 1;
    for (sampleNum = 0; sampleNum < scf->header.samples; sampleNum++) {
	Samples2 *sample = &samples[sampleNum];
	sample->sample_A *= scale;
	sample->sample_C *= scale;
	sample->sample_G *= scale;
	sample->sample_T *= scale;
    }
}
